@@ -118,7 +118,7 @@ class FtpUrl(internpaturl.InternPatternUrl):
             # file found
             return
         # it could be a directory if the trailing slash was forgotten
-        if "%s/" % self.filename in files:
+        if f"{self.filename}/" in files:
             if not self.url.endswith('/'):
                 self.add_warning(
                     _("Missing trailing directory slash in ftp url."),
@@ -154,12 +154,7 @@ class FtpUrl(internpaturl.InternPatternUrl):
         """See if URL target is parseable for recursion."""
         if self.is_directory():
             return True
-        if self.content_type in self.ContentMimetypes:
-            return True
-        log.debug(
-            LOG_CHECK, "URL with content type %r is not parseable.", self.content_type
-        )
-        return False
+        return self.is_content_type_parseable()
 
     def is_directory(self):
         """See if URL target is a directory."""
@@ -171,6 +166,7 @@ class FtpUrl(internpaturl.InternPatternUrl):
         """Set URL content type, or an empty string if content
         type could not be found."""
         self.content_type = mimeutil.guess_mimetype(self.url, read=self.get_content)
+        log.debug(LOG_CHECK, "MIME type: %s", self.content_type)
 
     def read_content(self):
         """Return URL target content, or in case of directories a dummy HTML
@@ -182,7 +178,7 @@ class FtpUrl(internpaturl.InternPatternUrl):
             data = get_index_html(self.files)
         else:
             # download file in BINARY mode
-            ftpcmd = "RETR %s" % self.filename
+            ftpcmd = f"RETR {self.filename}"
             buf = StringIO()
 
             def stor_data(s):
