@@ -23,7 +23,6 @@ from urllib.request import urlopen
 import time
 import errno
 import socket
-import select
 from io import BytesIO
 
 from . import absolute_url, get_url_from
@@ -44,6 +43,7 @@ from .const import (
     WARN_URL_OBFUSCATED_IP,
     WARN_URL_CONTENT_SIZE_ZERO,
     WARN_URL_CONTENT_SIZE_TOO_LARGE,
+    WARN_URL_CONTENT_TYPE_UNPARSEABLE,
     WARN_URL_WHITESPACE,
     URL_MAX_LENGTH,
     WARN_URL_TOO_LONG,
@@ -92,6 +92,7 @@ class UrlBase:
         # should not send this content type. They send text/html instead.
         "application/x-httpd-php": "html",
         "text/css": "css",
+        "application/vnd.adobe.flash.movie": "swf",
         "application/x-shockwave-flash": "swf",
         "application/msword": "word",
         "text/plain+linkchecker": "text",
@@ -214,6 +215,7 @@ class UrlBase:
                 % {"url": base_url},
                 tag=WARN_URL_WHITESPACE,
             )
+        self.ignore_errors = self.aggregate.config['ignoreerrors']
 
     def reset(self):
         """
@@ -224,7 +226,7 @@ class UrlBase:
         # This the real url we use when checking so it also referred to
         # as 'real url'
         self.url = None
-        # a splitted version of url for convenience
+        # a split version of url for convenience
         self.urlparts = None
         # the scheme, host, port and anchor part of url
         self.scheme = self.host = self.port = self.anchor = None
@@ -250,6 +252,8 @@ class UrlBase:
         self.url_connection = None
         # data of url content,  (data == None) means no data is available
         self.data = None
+        # url content data encoding
+        self.content_encoding = None
         # url content as a Unicode string
         self.text = None
         # url content as a Beautiful Soup object
@@ -268,6 +272,8 @@ class UrlBase:
         self.content_type = ""
         # URLs seen through redirections
         self.aliases = []
+        # error messages (regular expressions) to ignore
+        self.ignore_errors = []
 
     def set_result(self, msg, valid=True, overwrite=False):
         """
@@ -287,6 +293,16 @@ class UrlBase:
             log.warn(LOG_CHECK, "Empty result for %s", self)
         self.result = msg
         self.valid = valid
+
+        if not self.valid:
+            for url_regex, msg_regex in self.ignore_errors:
+                if not url_regex.search(self.url):
+                    continue
+                if not msg_regex.search(self.result):
+                    continue
+                self.valid = True
+                self.result = f"Ignored: {self.result}"
+
         # free content data
         self.data = None
 
@@ -306,6 +322,24 @@ class UrlBase:
                     self.title = title
         return self.title
 
+    def is_content_type_parseable(self):
+        """
+        Return True iff the content type of this url is parseable.
+        """
+        if self.content_type in self.ContentMimetypes:
+            return True
+        log.debug(
+            LOG_CHECK,
+            "URL with content type %r is not parseable",
+            self.content_type,
+        )
+        if self.recursion_level == 0:
+            self.add_warning(
+                _("The URL with content type %r is not parseable.") % self.content_type,
+                tag=WARN_URL_CONTENT_TYPE_UNPARSEABLE,
+            )
+        return False
+
     def is_parseable(self):
         """
         Return True iff content of this url is parseable.
@@ -423,7 +457,7 @@ class UrlBase:
                 self.base_ref = urljoin(self.parent_url, self.base_ref)
             self.url = urljoin(self.base_ref, base_url)
         elif self.parent_url:
-            # strip the parent url query and anchor
+            # strip the parent url anchor
             urlparts = list(urllib.parse.urlsplit(self.parent_url))
             urlparts[4] = ""
             parent_url = urlutil.urlunsplit(urlparts)
@@ -472,12 +506,12 @@ class UrlBase:
         if not self.port or self.port == urlutil.default_ports.get(self.scheme):
             host = self.host
         else:
-            host = "%s:%d" % (self.host, self.port)
+            host = f"{self.host}:{self.port}"
         if self.userinfo:
-            urlparts[1] = "%s@%s" % (self.userinfo, host)
+            urlparts[1] = f"{self.userinfo}@{host}"
         else:
             urlparts[1] = host
-        # safe anchor for later checking
+        # save anchor for later checking
         self.anchor = split.fragment
         if self.anchor is not None:
             assert isinstance(self.anchor, str), repr(self.anchor)
@@ -503,7 +537,7 @@ class UrlBase:
             trace.trace_on()
         try:
             self.local_check()
-        except (socket.error, select.error):
+        except OSError:
             # on Unix, ctrl-c can raise
             # error: (4, 'Interrupted system call')
             etype, value = sys.exc_info()[:2]
@@ -589,7 +623,7 @@ class UrlBase:
         # format message "<exception name>: <error message>"
         errmsg = etype.__name__
         if evalue:
-            errmsg += ": %s" % evalue
+            errmsg += f": {evalue}"
         # limit length to 240
         return strformat.limit(errmsg, length=240)
 
@@ -690,7 +724,7 @@ class UrlBase:
         pass
 
     def can_get_content(self):
-        """Indicate wether url get_content() can be called."""
+        """Indicate whether url get_content() can be called."""
         return self.size <= self.aggregate.config["maxfilesizedownload"]
 
     def download_content(self):
@@ -726,9 +760,9 @@ class UrlBase:
             log.debug(
                 LOG_CHECK, "Beautiful Soup detected %s", self.soup.original_encoding
             )
-            self.encoding = self.soup.original_encoding or 'ISO-8859-1'
-            log.debug(LOG_CHECK, "Content encoding %s", self.encoding)
-            self.text = self.data.decode(self.encoding)
+            self.content_encoding = self.soup.original_encoding or 'ISO-8859-1'
+            log.debug(LOG_CHECK, "Content encoding %s", self.content_encoding)
+            self.text = self.data.decode(self.content_encoding)
         return self.text
 
     def read_content(self):
@@ -758,24 +792,24 @@ class UrlBase:
             return (split.username, split.password)
         return self.aggregate.config.get_user_password(self.url)
 
-    def add_url(self, url, line=0, column=0, page=0, name="", base=None):
+    def add_url(self, url, line=0, column=0, page=0, name="", base=None, parent=None):
         """Add new URL to queue."""
         if base:
-            base_ref = urlutil.url_norm(base, encoding=self.encoding)[0]
+            base_ref = urlutil.url_norm(base, encoding=self.content_encoding)[0]
         else:
             base_ref = None
         url_data = get_url_from(
             url,
             self.recursion_level + 1,
             self.aggregate,
-            parent_url=self.url,
+            parent_url=self.url if parent is None else parent,
             base_ref=base_ref,
             line=line,
             column=column,
             page=page,
             name=name,
             parent_content_type=self.content_type,
-            url_encoding=self.encoding,
+            url_encoding=self.content_encoding,
         )
         self.aggregate.urlqueue.put(url_data)
 
@@ -847,7 +881,7 @@ class UrlBase:
         @return: URL info
         @rtype: unicode
         """
-        return "<%s>" % self.serialized(sep=", ")
+        return f'<{self.serialized(sep=", ")}>'
 
     def to_wire_dict(self):
         """Return a simplified transport object for logging and caching.
@@ -956,6 +990,6 @@ class CompactUrlData:
     __slots__ = urlDataAttr
 
     def __init__(self, wired_url_data):
-        '''Set all attributes according to the dictionnary wired_url_data'''
+        '''Set all attributes according to the dictionary wired_url_data'''
         for attr in urlDataAttr:
             setattr(self, attr, wired_url_data[attr])
