@@ -1,4 +1,3 @@
-# -*- coding: iso-8859-1 -*-
 # Copyright (C) 2005-2014 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
@@ -18,13 +17,12 @@
 Parsing of cookies.
 """
 
-import cookielib
-import httplib
+from http.cookiejar import split_header_words
+import email
 import requests
-from cStringIO import StringIO
 
 
-def from_file (filename):
+def from_file(filename):
     """Parse cookie data from a text file in HTTP header format.
 
     @return: list of tuples (headers, scheme, host, path)
@@ -36,33 +34,34 @@ def from_file (filename):
             line = line.rstrip()
             if not line:
                 if lines:
-                    entries.append(from_headers("\r\n".join(lines)))
+                    entries.extend(from_headers("\r\n".join(lines)))
                 lines = []
             else:
                 lines.append(line)
         if lines:
-            entries.append(from_headers("\r\n".join(lines)))
+            entries.extend(from_headers("\r\n".join(lines)))
         return entries
 
 
-def from_headers (strheader):
+def from_headers(strheader):
     """Parse cookie data from a string in HTTP header (RFC 2616) format.
 
     @return: list of cookies
     @raises: ValueError for incomplete or invalid data
     """
     res = []
-    fp = StringIO(strheader)
-    headers = httplib.HTTPMessage(fp, seekable=True)
+    headers = email.message_from_string(strheader)
     if "Host" not in headers:
         raise ValueError("Required header 'Host:' missing")
     host = headers["Host"]
-    path= headers.get("Path", "/")
-    for header in headers.getallmatchingheaders("Set-Cookie"):
-        headervalue = header.split(':', 1)[1]
-        for pairs in cookielib.split_header_words([headervalue]):
+    # XXX: our --help says we also pay attention to the Scheme: header,
+    # but we don't?!
+    path = headers.get("Path", "/")
+    for headervalue in headers.get_all("Set-Cookie"):
+        for pairs in split_header_words([headervalue]):
             for name, value in pairs:
-                cookie = requests.cookies.create_cookie(name, value,
-                    domain=host, path=path)
+                cookie = requests.cookies.create_cookie(
+                    name, value, domain=host, path=path
+                )
                 res.append(cookie)
     return res
