@@ -13,50 +13,24 @@
 # You should have received a copy of the GNU General Public License along
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-from datetime import datetime
-
 
 def x509_to_dict(x509):
     """Parse a x509 pyopenssl object to a dictionary with keys
     subject, subjectAltName and optional notAfter.
     """
-    from requests.packages.urllib3.contrib.pyopenssl import get_subj_alt_name
+    from cryptography.x509 import DNSName, SubjectAlternativeName
+
+    crypto_cert = x509.to_cryptography()
+    ext = crypto_cert.extensions.get_extension_for_class(SubjectAlternativeName)
 
     res = {
         'subject': ((('commonName', x509.get_subject().CN),),),
-        'subjectAltName': [('DNS', value) for value in get_subj_alt_name(x509)]
+        'subjectAltName': [
+            ('DNS', value) for value in ext.value.get_values_for_type(DNSName)]
     }
-    notAfter = x509.get_notAfter()
+    notAfter = crypto_cert.not_valid_after
     if notAfter is not None:
-        notAfter = notAfter.decode()
-        parsedtime = asn1_generaltime_to_seconds(notAfter)
-        if parsedtime is not None:
-            res['notAfter'] = parsedtime.strftime('%b %d %H:%M:%S %Y')
-            if parsedtime.tzinfo is None:
-                res['notAfter'] += ' GMT'
-        else:
-            # give up parsing, just set the string
-            res['notAfter'] = notAfter
-    return res
-
-
-def asn1_generaltime_to_seconds(timestr):
-    """The given string has one of the following formats
-    YYYYMMDDhhmmssZ
-    YYYYMMDDhhmmss+hhmm
-    YYYYMMDDhhmmss-hhmm
-
-    @return: a datetime object or None on error
-    """
-    res = None
-    timeformat = "%Y%m%d%H%M%S"
-    try:
-        res = datetime.strptime(timestr, timeformat + 'Z')
-    except ValueError:
-        try:
-            res = datetime.strptime(timestr, timeformat + '%z')
-        except ValueError:
-            pass
+        res['notAfter'] = notAfter.strftime('%b %d %H:%M:%S %Y GMT')
     return res
 
 
