@@ -29,7 +29,7 @@ for scheme in ('ldap', 'irc'):
 # http://tools.ietf.org/html/rfc2396#section-2.1
 # Note that the encoding is not really specified, but most browsers
 # encode in UTF-8 when no encoding is specified by the HTTP headers,
-# else they use the page encoding for followed link. See als
+# else they use the page encoding for followed link. See also
 # http://code.google.com/p/browsersec/wiki/Part1#Unicode_in_URLs
 url_encoding = "utf-8"
 
@@ -43,36 +43,34 @@ default_ports = {
 # adapted from David Wheelers "Secure Programming for Linux and Unix HOWTO"
 # http://www.dwheeler.com/secure-programs/Secure-Programs-HOWTO/\
 # filter-html.html#VALIDATING-URIS
-_basic = {
-    "_path": r"\-\_\.\!\~\*\'\(\),",
-    "_hex_safe": r"2-9a-f",
-    "_hex_full": r"0-9a-f",
-    "_part": r"([a-z0-9][-a-z0-9]{0,61}|[a-z])",
-}
+_path = r"\-\_\.\!\~\*\'\(\),"
+_hex_safe = r"2-9a-f"
+_hex_full = r"0-9a-f"
+_part = r"([a-z0-9][-a-z0-9]{0,61}|[a-z])"
 _safe_char = (
-    r"([a-z0-9%(_path)s\+]|"
-    r"(%%[%(_hex_safe)s][%(_hex_full)s]))" % _basic
+    fr"([a-z0-9{_path}\+]|"
+    fr"(%[{_hex_safe}][{_hex_full}]))"
 )
 _safe_scheme_pattern = r"(https?|ftp)"
-_safe_domain_pattern = r"(%(_part)s(\.%(_part)s)*\.?)" % _basic
-_safe_host_pattern = _safe_domain_pattern + r"(:(80|8080|8000|443))?" % _basic
+_safe_domain_pattern = fr"({_part}(\.{_part})*\.?)"
+_safe_host_pattern = fr"{_safe_domain_pattern}(:(80|8080|8000|443))?"
 _safe_path_pattern = (
-    r"((/([a-z0-9%(_path)s]|"
-    r"(%%[%(_hex_safe)s][%(_hex_full)s]))+)*/?)" % _basic
+    fr"((/([a-z0-9{_path}]|"
+    fr"(%[{_hex_safe}][{_hex_full}]))+)*/?)"
 )
-_safe_fragment_pattern = r"%s*" % _safe_char
-_safe_cgi = r"%s+(=(%s|/)+)?" % (_safe_char, _safe_char)
-_safe_query_pattern = r"(%s(&%s)*)?" % (_safe_cgi, _safe_cgi)
-_safe_param_pattern = r"(%s(;%s)*)?" % (_safe_cgi, _safe_cgi)
-safe_url_pattern = r"%s://%s%s(#%s)?" % (
+_safe_fragment_pattern = fr"{_safe_char}*"
+_safe_cgi = fr"{_safe_char}+(=({_safe_char}|/)+)?"
+_safe_query_pattern = fr"({_safe_cgi}(&{_safe_cgi})*)?"
+_safe_param_pattern = fr"({_safe_cgi}(;{_safe_cgi})*)?"
+safe_url_pattern = r"{}://{}{}(#{})?".format(
     _safe_scheme_pattern,
     _safe_host_pattern,
     _safe_path_pattern,
     _safe_fragment_pattern,
 )
 
-is_safe_url = re.compile("(?i)^%s$" % safe_url_pattern).match
-is_safe_domain = re.compile("(?i)^%s$" % _safe_domain_pattern).match
+is_safe_url = re.compile(f"(?i)^{safe_url_pattern}$").match
+is_safe_domain = re.compile(f"(?i)^{_safe_domain_pattern}$").match
 
 
 # snatched form urlparse.py
@@ -117,7 +115,7 @@ def parse_qsl(qs, encoding, keep_blank_values=0, strict_parsing=0):
         errors raise a ValueError exception.
     @type strict_parsing: bool
     @returns: list of triples (key, value, separator) where key and value
-      are the splitted CGI parameter and separator the used separator
+      are the split CGI parameter and separator the used separator
       for this CGI parameter which is either a semicolon or an ampersand
     @rtype: list of triples
     """
@@ -195,7 +193,7 @@ def url_fix_host(urlparts, encoding):
         if not urlparts[2] or urlparts[2] == '/':
             urlparts[2] = comps
         else:
-            urlparts[2] = "%s%s" % (
+            urlparts[2] = "{}{}".format(
                 comps,
                 urllib.parse.unquote(urlparts[2], encoding=encoding),
             )
@@ -219,7 +217,7 @@ def url_fix_host(urlparts, encoding):
         if host.endswith("."):
             host = host[:-1]
         if port != dport:
-            host = "%s:%d" % (host, port)
+            host = f"{host}:{port}"
         netloc = host
     urlparts[1] = userpass + netloc
     return is_idn
@@ -255,12 +253,12 @@ def url_parse_query(query, encoding):
         k = urllib.parse.quote(k, safe='/-:,;')
         if v:
             v = urllib.parse.quote(v, safe='/-:,;')
-            f.append("%s=%s%s" % (k, v, sep))
+            f.append(f"{k}={v}{sep}")
         elif v is None:
-            f.append("%s%s" % (k, sep))
+            f.append(f"{k}{sep}")
         else:
             # some sites do not work when the equal sign is missing
-            f.append("%s=%s" % (k, sep))
+            f.append(f"{k}={sep}")
     return ''.join(f) + append
 
 
@@ -381,9 +379,9 @@ def url_quote(url, encoding):
         k = urllib.parse.quote(k, safe='/-:,;')
         if v:
             v = urllib.parse.quote(v, safe='/-:,;')
-            f.append("%s=%s%s" % (k, v, sep))
+            f.append(f"{k}={v}{sep}")
         else:
-            f.append("%s%s" % (k, sep))
+            f.append(f"{k}{sep}")
     urlparts[3] = ''.join(f)
     urlparts[4] = urllib.parse.quote(urlparts[4])  # anchor
     return urlunsplit(urlparts)
@@ -397,7 +395,7 @@ def document_quote(document):
         query = None
     doc = urllib.parse.quote(doc, safe='/=,')
     if query:
-        return "%s?%s" % (doc, query)
+        return f"{doc}?{query}"
     return doc
 
 
@@ -405,7 +403,7 @@ _nopathquote_chars = "-;/=,~*+()@!"
 if os.name == 'nt':
     _nopathquote_chars += "|"
 _safe_url_chars = re.escape(_nopathquote_chars + "_:.&#%?[]!") + "a-zA-Z0-9"
-_safe_url_chars_ro = re.compile(r"^[%s]*$" % _safe_url_chars)
+_safe_url_chars_ro = re.compile(fr"^[{_safe_url_chars}]*$")
 
 
 def url_needs_quoting(url):
